package com.cpms.project.asset.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cpms.project.asset.mapper.TAssetBasedocMapper;
import com.cpms.project.asset.domain.TAssetBasedoc;
import com.cpms.project.asset.service.ITAssetBasedocService;

/**
 * 资产管理基础文档清单Service业务层处理
 * 
 * @author admin
 * @date 2024-04-18
 */
@Service
public class TAssetBasedocServiceImpl implements ITAssetBasedocService 
{
    @Autowired
    private TAssetBasedocMapper tAssetBasedocMapper;

    /**
     * 查询资产管理基础文档清单
     * 
     * @param id 资产管理基础文档清单主键
     * @return 资产管理基础文档清单
     */
    @Override
    public TAssetBasedoc selectTAssetBasedocById(Long id)
    {
        return tAssetBasedocMapper.selectTAssetBasedocById(id);
    }

    /**
     * 查询资产管理基础文档清单列表
     * 
     * @param tAssetBasedoc 资产管理基础文档清单
     * @return 资产管理基础文档清单
     */
    @Override
    public List<TAssetBasedoc> selectTAssetBasedocList(TAssetBasedoc tAssetBasedoc)
    {
        return tAssetBasedocMapper.selectTAssetBasedocList(tAssetBasedoc);
    }

    /**
     * 新增资产管理基础文档清单
     * 
     * @param tAssetBasedoc 资产管理基础文档清单
     * @return 结果
     */
    @Override
    public int insertTAssetBasedoc(TAssetBasedoc tAssetBasedoc)
    {
        return tAssetBasedocMapper.insertTAssetBasedoc(tAssetBasedoc);
    }

    /**
     * 修改资产管理基础文档清单
     * 
     * @param tAssetBasedoc 资产管理基础文档清单
     * @return 结果
     */
    @Override
    public int updateTAssetBasedoc(TAssetBasedoc tAssetBasedoc)
    {
        return tAssetBasedocMapper.updateTAssetBasedoc(tAssetBasedoc);
    }

    /**
     * 批量删除资产管理基础文档清单
     * 
     * @param ids 需要删除的资产管理基础文档清单主键
     * @return 结果
     */
    @Override
    public int deleteTAssetBasedocByIds(Long[] ids)
    {
        return tAssetBasedocMapper.deleteTAssetBasedocByIds(ids);
    }

    /**
     * 删除资产管理基础文档清单信息
     * 
     * @param id 资产管理基础文档清单主键
     * @return 结果
     */
    @Override
    public int deleteTAssetBasedocById(Long id)
    {
        return tAssetBasedocMapper.deleteTAssetBasedocById(id);
    }
}
